@@ -1,8 +1,31 @@
 
-#include <src/ReceiveProgressDialog.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <gtk/gtk.h>
+#include <stdlib.h>
+#include <string.h>
+#include <gdk/gdk.h>
 
 
+#define MOSERIAL_TYPE_RECEIVE_PROGRESS_DIALOG (moserial_receive_progress_dialog_get_type ())
+#define MOSERIAL_RECEIVE_PROGRESS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MOSERIAL_TYPE_RECEIVE_PROGRESS_DIALOG, moserialReceiveProgressDialog))
+#define MOSERIAL_RECEIVE_PROGRESS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MOSERIAL_TYPE_RECEIVE_PROGRESS_DIALOG, moserialReceiveProgressDialogClass))
+#define MOSERIAL_IS_RECEIVE_PROGRESS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MOSERIAL_TYPE_RECEIVE_PROGRESS_DIALOG))
+#define MOSERIAL_IS_RECEIVE_PROGRESS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MOSERIAL_TYPE_RECEIVE_PROGRESS_DIALOG))
+#define MOSERIAL_RECEIVE_PROGRESS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MOSERIAL_TYPE_RECEIVE_PROGRESS_DIALOG, moserialReceiveProgressDialogClass))
 
+typedef struct _moserialReceiveProgressDialog moserialReceiveProgressDialog;
+typedef struct _moserialReceiveProgressDialogClass moserialReceiveProgressDialogClass;
+typedef struct _moserialReceiveProgressDialogPrivate moserialReceiveProgressDialogPrivate;
+
+struct _moserialReceiveProgressDialog {
+	GObject parent_instance;
+	moserialReceiveProgressDialogPrivate * priv;
+};
+
+struct _moserialReceiveProgressDialogClass {
+	GObjectClass parent_class;
+};
 
 struct _moserialReceiveProgressDialogPrivate {
 	GtkBuilder* _builder;
@@ -12,17 +35,29 @@ struct _moserialReceiveProgressDialogPrivate {
 	GtkProgressBar* progressBar;
 };
 
+
+static gpointer moserial_receive_progress_dialog_parent_class = NULL;
+
+GType moserial_receive_progress_dialog_get_type (void);
 #define MOSERIAL_RECEIVE_PROGRESS_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), MOSERIAL_TYPE_RECEIVE_PROGRESS_DIALOG, moserialReceiveProgressDialogPrivate))
 enum  {
 	MOSERIAL_RECEIVE_PROGRESS_DIALOG_DUMMY_PROPERTY,
 	MOSERIAL_RECEIVE_PROGRESS_DIALOG_BUILDER
 };
 static void moserial_receive_progress_dialog_set_builder (moserialReceiveProgressDialog* self, GtkBuilder* value);
+moserialReceiveProgressDialog* moserial_receive_progress_dialog_new (GtkBuilder* builder);
+moserialReceiveProgressDialog* moserial_receive_progress_dialog_construct (GType object_type, GtkBuilder* builder);
+void moserial_receive_progress_dialog_show (moserialReceiveProgressDialog* self);
+gboolean moserial_receive_progress_dialog_hide (moserialReceiveProgressDialog* self);
+void moserial_receive_progress_dialog_updateStatus (moserialReceiveProgressDialog* self, GObject* o, const char* newStatus);
+void moserial_receive_progress_dialog_cancel (moserialReceiveProgressDialog* self, GObject* o);
+GtkBuilder* moserial_receive_progress_dialog_get_builder (moserialReceiveProgressDialog* self);
 static void _moserial_receive_progress_dialog_cancel_gtk_button_clicked (GtkButton* _sender, gpointer self);
-static gboolean _moserial_receive_progress_dialog_hide_gtk_widget_delete_event (GtkDialog* _sender, const GdkEvent* event, gpointer self);
+static gboolean _moserial_receive_progress_dialog_hide_gtk_widget_delete_event (GtkDialog* _sender, GdkEvent* event, gpointer self);
 static GObject * moserial_receive_progress_dialog_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
-static gpointer moserial_receive_progress_dialog_parent_class = NULL;
 static void moserial_receive_progress_dialog_finalize (GObject* obj);
+static void moserial_receive_progress_dialog_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
+static void moserial_receive_progress_dialog_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
 
 
 
@@ -60,9 +95,11 @@ void moserial_receive_progress_dialog_show (moserialReceiveProgressDialog* self)
 
 
 gboolean moserial_receive_progress_dialog_hide (moserialReceiveProgressDialog* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
 	gtk_widget_hide_all ((GtkWidget*) self->priv->dialog);
-	return TRUE;
+	result = TRUE;
+	return result;
 }
 
 
@@ -84,18 +121,20 @@ void moserial_receive_progress_dialog_cancel (moserialReceiveProgressDialog* sel
 
 
 GtkBuilder* moserial_receive_progress_dialog_get_builder (moserialReceiveProgressDialog* self) {
+	GtkBuilder* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_builder;
+	result = self->priv->_builder;
+	return result;
 }
 
 
 static void moserial_receive_progress_dialog_set_builder (moserialReceiveProgressDialog* self, GtkBuilder* value) {
-	GtkBuilder* _tmp2;
-	GtkBuilder* _tmp1;
+	GtkBuilder* _tmp1_;
+	GtkBuilder* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_builder = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_builder == NULL) ? NULL : (self->priv->_builder = (g_object_unref (self->priv->_builder), NULL)), _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_builder = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_object_ref (_tmp0_)), (self->priv->_builder == NULL) ? NULL : (self->priv->_builder = (g_object_unref (self->priv->_builder), NULL)), _tmp1_);
 	g_object_notify ((GObject *) self, "builder");
 }
 
@@ -105,7 +144,7 @@ static void _moserial_receive_progress_dialog_cancel_gtk_button_clicked (GtkButt
 }
 
 
-static gboolean _moserial_receive_progress_dialog_hide_gtk_widget_delete_event (GtkDialog* _sender, const GdkEvent* event, gpointer self) {
+static gboolean _moserial_receive_progress_dialog_hide_gtk_widget_delete_event (GtkDialog* _sender, GdkEvent* event, gpointer self) {
 	return moserial_receive_progress_dialog_hide (self);
 }
 
@@ -120,62 +159,33 @@ static GObject * moserial_receive_progress_dialog_constructor (GType type, guint
 	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
 	self = MOSERIAL_RECEIVE_PROGRESS_DIALOG (obj);
 	{
-		GtkDialog* _tmp1;
-		GtkDialog* _tmp0;
-		GtkButton* _tmp3;
-		GtkButton* _tmp2;
-		GtkLabel* _tmp5;
-		GtkLabel* _tmp4;
-		GtkProgressBar* _tmp7;
-		GtkProgressBar* _tmp6;
-		_tmp1 = NULL;
-		_tmp0 = NULL;
-		self->priv->dialog = (_tmp1 = (_tmp0 = GTK_DIALOG (gtk_builder_get_object (self->priv->_builder, "receive_progress_dialog")), (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (self->priv->dialog == NULL) ? NULL : (self->priv->dialog = (g_object_unref (self->priv->dialog), NULL)), _tmp1);
-		_tmp3 = NULL;
-		_tmp2 = NULL;
-		self->priv->cancelButton = (_tmp3 = (_tmp2 = GTK_BUTTON (gtk_builder_get_object (self->priv->_builder, "receive_progress_cancel")), (_tmp2 == NULL) ? NULL : g_object_ref (_tmp2)), (self->priv->cancelButton == NULL) ? NULL : (self->priv->cancelButton = (g_object_unref (self->priv->cancelButton), NULL)), _tmp3);
+		GtkDialog* _tmp1_;
+		GtkDialog* _tmp0_;
+		GtkButton* _tmp3_;
+		GtkButton* _tmp2_;
+		GtkLabel* _tmp5_;
+		GtkLabel* _tmp4_;
+		GtkProgressBar* _tmp7_;
+		GtkProgressBar* _tmp6_;
+		_tmp1_ = NULL;
+		_tmp0_ = NULL;
+		self->priv->dialog = (_tmp1_ = (_tmp0_ = GTK_DIALOG (gtk_builder_get_object (self->priv->_builder, "receive_progress_dialog")), (_tmp0_ == NULL) ? NULL : g_object_ref (_tmp0_)), (self->priv->dialog == NULL) ? NULL : (self->priv->dialog = (g_object_unref (self->priv->dialog), NULL)), _tmp1_);
+		_tmp3_ = NULL;
+		_tmp2_ = NULL;
+		self->priv->cancelButton = (_tmp3_ = (_tmp2_ = GTK_BUTTON (gtk_builder_get_object (self->priv->_builder, "receive_progress_cancel")), (_tmp2_ == NULL) ? NULL : g_object_ref (_tmp2_)), (self->priv->cancelButton == NULL) ? NULL : (self->priv->cancelButton = (g_object_unref (self->priv->cancelButton), NULL)), _tmp3_);
 		g_signal_connect_object (self->priv->cancelButton, "clicked", (GCallback) _moserial_receive_progress_dialog_cancel_gtk_button_clicked, self, 0);
-		_tmp5 = NULL;
-		_tmp4 = NULL;
-		self->priv->status = (_tmp5 = (_tmp4 = GTK_LABEL (gtk_builder_get_object (self->priv->_builder, "receive_statusbox")), (_tmp4 == NULL) ? NULL : g_object_ref (_tmp4)), (self->priv->status == NULL) ? NULL : (self->priv->status = (g_object_unref (self->priv->status), NULL)), _tmp5);
-		_tmp7 = NULL;
-		_tmp6 = NULL;
-		self->priv->progressBar = (_tmp7 = (_tmp6 = GTK_PROGRESS_BAR (gtk_builder_get_object (self->priv->_builder, "receive_progressbar")), (_tmp6 == NULL) ? NULL : g_object_ref (_tmp6)), (self->priv->progressBar == NULL) ? NULL : (self->priv->progressBar = (g_object_unref (self->priv->progressBar), NULL)), _tmp7);
+		_tmp5_ = NULL;
+		_tmp4_ = NULL;
+		self->priv->status = (_tmp5_ = (_tmp4_ = GTK_LABEL (gtk_builder_get_object (self->priv->_builder, "receive_statusbox")), (_tmp4_ == NULL) ? NULL : g_object_ref (_tmp4_)), (self->priv->status == NULL) ? NULL : (self->priv->status = (g_object_unref (self->priv->status), NULL)), _tmp5_);
+		_tmp7_ = NULL;
+		_tmp6_ = NULL;
+		self->priv->progressBar = (_tmp7_ = (_tmp6_ = GTK_PROGRESS_BAR (gtk_builder_get_object (self->priv->_builder, "receive_progressbar")), (_tmp6_ == NULL) ? NULL : g_object_ref (_tmp6_)), (self->priv->progressBar == NULL) ? NULL : (self->priv->progressBar = (g_object_unref (self->priv->progressBar), NULL)), _tmp7_);
 		g_signal_connect_object ((GtkWidget*) self->priv->dialog, "delete-event", (GCallback) _moserial_receive_progress_dialog_hide_gtk_widget_delete_event, self, 0);
 	}
 	return obj;
 }
 
 
-static void moserial_receive_progress_dialog_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	moserialReceiveProgressDialog * self;
-	gpointer boxed;
-	self = MOSERIAL_RECEIVE_PROGRESS_DIALOG (object);
-	switch (property_id) {
-		case MOSERIAL_RECEIVE_PROGRESS_DIALOG_BUILDER:
-		g_value_set_object (value, moserial_receive_progress_dialog_get_builder (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void moserial_receive_progress_dialog_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	moserialReceiveProgressDialog * self;
-	self = MOSERIAL_RECEIVE_PROGRESS_DIALOG (object);
-	switch (property_id) {
-		case MOSERIAL_RECEIVE_PROGRESS_DIALOG_BUILDER:
-		moserial_receive_progress_dialog_set_builder (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void moserial_receive_progress_dialog_class_init (moserialReceiveProgressDialogClass * klass) {
 	moserial_receive_progress_dialog_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (moserialReceiveProgressDialogPrivate));
@@ -215,5 +225,34 @@ GType moserial_receive_progress_dialog_get_type (void) {
 }
 
 
+static void moserial_receive_progress_dialog_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
+	moserialReceiveProgressDialog * self;
+	gpointer boxed;
+	self = MOSERIAL_RECEIVE_PROGRESS_DIALOG (object);
+	switch (property_id) {
+		case MOSERIAL_RECEIVE_PROGRESS_DIALOG_BUILDER:
+		g_value_set_object (value, moserial_receive_progress_dialog_get_builder (self));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
+
+static void moserial_receive_progress_dialog_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
+	moserialReceiveProgressDialog * self;
+	self = MOSERIAL_RECEIVE_PROGRESS_DIALOG (object);
+	switch (property_id) {
+		case MOSERIAL_RECEIVE_PROGRESS_DIALOG_BUILDER:
+		moserial_receive_progress_dialog_set_builder (self, g_value_get_object (value));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
+
 
 
