@@ -1,27 +1,62 @@
 
-#include <src/SendChooserDialog.h>
-#include "src/MoUtils.h"
+#include <glib.h>
+#include <glib-object.h>
+#include <gtk/gtk.h>
+#include <stdlib.h>
+#include <string.h>
+#include <gdk/gdk.h>
 
 
+#define MOSERIAL_TYPE_SEND_CHOOSER_DIALOG (moserial_send_chooser_dialog_get_type ())
+#define MOSERIAL_SEND_CHOOSER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MOSERIAL_TYPE_SEND_CHOOSER_DIALOG, moserialSendChooserDialog))
+#define MOSERIAL_SEND_CHOOSER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MOSERIAL_TYPE_SEND_CHOOSER_DIALOG, moserialSendChooserDialogClass))
+#define MOSERIAL_IS_SEND_CHOOSER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MOSERIAL_TYPE_SEND_CHOOSER_DIALOG))
+#define MOSERIAL_IS_SEND_CHOOSER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MOSERIAL_TYPE_SEND_CHOOSER_DIALOG))
+#define MOSERIAL_SEND_CHOOSER_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MOSERIAL_TYPE_SEND_CHOOSER_DIALOG, moserialSendChooserDialogClass))
 
+typedef struct _moserialSendChooserDialog moserialSendChooserDialog;
+typedef struct _moserialSendChooserDialogClass moserialSendChooserDialogClass;
+typedef struct _moserialSendChooserDialogPrivate moserialSendChooserDialogPrivate;
+
+struct _moserialSendChooserDialog {
+	GObject parent_instance;
+	moserialSendChooserDialogPrivate * priv;
+	GtkComboBox* protocolCombo;
+	char* filename;
+};
+
+struct _moserialSendChooserDialogClass {
+	GObjectClass parent_class;
+};
 
 struct _moserialSendChooserDialogPrivate {
 	GtkBuilder* _builder;
 	GtkFileChooserDialog* dialog;
 };
 
+
+static gpointer moserial_send_chooser_dialog_parent_class = NULL;
+
+GType moserial_send_chooser_dialog_get_type (void);
 #define MOSERIAL_SEND_CHOOSER_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), MOSERIAL_TYPE_SEND_CHOOSER_DIALOG, moserialSendChooserDialogPrivate))
 enum  {
 	MOSERIAL_SEND_CHOOSER_DIALOG_DUMMY_PROPERTY,
 	MOSERIAL_SEND_CHOOSER_DIALOG_BUILDER
 };
-static void moserial_send_chooser_dialog_response (moserialSendChooserDialog* self, GtkWidget* w, gint r);
 static void moserial_send_chooser_dialog_set_builder (moserialSendChooserDialog* self, GtkBuilder* value);
-static gboolean _moserial_send_chooser_dialog_hide_gtk_widget_delete_event (GtkFileChooserDialog* _sender, const GdkEvent* event, gpointer self);
+moserialSendChooserDialog* moserial_send_chooser_dialog_new (GtkBuilder* builder);
+moserialSendChooserDialog* moserial_send_chooser_dialog_construct (GType object_type, GtkBuilder* builder);
+gboolean mo_utils_fileExists (const char* path);
+void moserial_send_chooser_dialog_show (moserialSendChooserDialog* self, const char* folder);
+gboolean moserial_send_chooser_dialog_hide (moserialSendChooserDialog* self);
+static void moserial_send_chooser_dialog_response (moserialSendChooserDialog* self, GtkWidget* w, gint r);
+GtkBuilder* moserial_send_chooser_dialog_get_builder (moserialSendChooserDialog* self);
+static gboolean _moserial_send_chooser_dialog_hide_gtk_widget_delete_event (GtkFileChooserDialog* _sender, GdkEvent* event, gpointer self);
 static void _moserial_send_chooser_dialog_response_gtk_dialog_response (GtkFileChooserDialog* _sender, gint response_id, gpointer self);
 static GObject * moserial_send_chooser_dialog_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
-static gpointer moserial_send_chooser_dialog_parent_class = NULL;
 static void moserial_send_chooser_dialog_finalize (GObject* obj);
+static void moserial_send_chooser_dialog_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
+static void moserial_send_chooser_dialog_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
 
 
 
@@ -52,15 +87,15 @@ moserialSendChooserDialog* moserial_send_chooser_dialog_new (GtkBuilder* builder
 
 
 void moserial_send_chooser_dialog_show (moserialSendChooserDialog* self, const char* folder) {
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (folder != NULL) {
-		_tmp0 = mo_utils_fileExists (folder);
+		_tmp0_ = mo_utils_fileExists (folder);
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	if (_tmp0) {
+	if (_tmp0_) {
 		gtk_file_chooser_set_current_folder ((GtkFileChooser*) self->priv->dialog, folder);
 	}
 	gtk_dialog_run ((GtkDialog*) self->priv->dialog);
@@ -68,9 +103,11 @@ void moserial_send_chooser_dialog_show (moserialSendChooserDialog* self, const c
 
 
 gboolean moserial_send_chooser_dialog_hide (moserialSendChooserDialog* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
 	gtk_widget_hide ((GtkWidget*) self->priv->dialog);
-	return TRUE;
+	result = TRUE;
+	return result;
 }
 
 
@@ -81,12 +118,10 @@ static void moserial_send_chooser_dialog_response (moserialSendChooserDialog* se
 		moserial_send_chooser_dialog_hide (self);
 	} else {
 		if (r == GTK_RESPONSE_ACCEPT) {
-			char* _tmp1;
-			const char* _tmp0;
+			char* _tmp0_;
 			moserial_send_chooser_dialog_hide (self);
-			_tmp1 = NULL;
-			_tmp0 = NULL;
-			self->filename = (_tmp1 = (_tmp0 = gtk_file_chooser_get_filename ((GtkFileChooser*) self->priv->dialog), (_tmp0 == NULL) ? NULL : g_strdup (_tmp0)), self->filename = (g_free (self->filename), NULL), _tmp1);
+			_tmp0_ = NULL;
+			self->filename = (_tmp0_ = gtk_file_chooser_get_filename ((GtkFileChooser*) self->priv->dialog), self->filename = (g_free (self->filename), NULL), _tmp0_);
 			g_signal_emit_by_name (self, "start-transfer");
 		} else {
 		}
@@ -95,23 +130,25 @@ static void moserial_send_chooser_dialog_response (moserialSendChooserDialog* se
 
 
 GtkBuilder* moserial_send_chooser_dialog_get_builder (moserialSendChooserDialog* self) {
+	GtkBuilder* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_builder;
+	result = self->priv->_builder;
+	return result;
 }
 
 
 static void moserial_send_chooser_dialog_set_builder (moserialSendChooserDialog* self, GtkBuilder* value) {
-	GtkBuilder* _tmp2;
-	GtkBuilder* _tmp1;
+	GtkBuilder* _tmp1_;
+	GtkBuilder* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_builder = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_builder == NULL) ? NULL : (self->priv->_builder = (g_object_unref (self->priv->_builder), NULL)), _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_builder = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_object_ref (_tmp0_)), (self->priv->_builder == NULL) ? NULL : (self->priv->_builder = (g_object_unref (self->priv->_builder), NULL)), _tmp1_);
 	g_object_notify ((GObject *) self, "builder");
 }
 
 
-static gboolean _moserial_send_chooser_dialog_hide_gtk_widget_delete_event (GtkFileChooserDialog* _sender, const GdkEvent* event, gpointer self) {
+static gboolean _moserial_send_chooser_dialog_hide_gtk_widget_delete_event (GtkFileChooserDialog* _sender, GdkEvent* event, gpointer self) {
 	return moserial_send_chooser_dialog_hide (self);
 }
 
@@ -131,16 +168,16 @@ static GObject * moserial_send_chooser_dialog_constructor (GType type, guint n_c
 	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
 	self = MOSERIAL_SEND_CHOOSER_DIALOG (obj);
 	{
-		GtkFileChooserDialog* _tmp1;
-		GtkFileChooserDialog* _tmp0;
-		GtkComboBox* _tmp3;
-		GtkComboBox* _tmp2;
-		_tmp1 = NULL;
-		_tmp0 = NULL;
-		self->priv->dialog = (_tmp1 = (_tmp0 = GTK_FILE_CHOOSER_DIALOG (gtk_builder_get_object (self->priv->_builder, "send_chooser_dialog")), (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (self->priv->dialog == NULL) ? NULL : (self->priv->dialog = (g_object_unref (self->priv->dialog), NULL)), _tmp1);
-		_tmp3 = NULL;
-		_tmp2 = NULL;
-		self->protocolCombo = (_tmp3 = (_tmp2 = GTK_COMBO_BOX (gtk_builder_get_object (self->priv->_builder, "send_chooser_protocol")), (_tmp2 == NULL) ? NULL : g_object_ref (_tmp2)), (self->protocolCombo == NULL) ? NULL : (self->protocolCombo = (g_object_unref (self->protocolCombo), NULL)), _tmp3);
+		GtkFileChooserDialog* _tmp1_;
+		GtkFileChooserDialog* _tmp0_;
+		GtkComboBox* _tmp3_;
+		GtkComboBox* _tmp2_;
+		_tmp1_ = NULL;
+		_tmp0_ = NULL;
+		self->priv->dialog = (_tmp1_ = (_tmp0_ = GTK_FILE_CHOOSER_DIALOG (gtk_builder_get_object (self->priv->_builder, "send_chooser_dialog")), (_tmp0_ == NULL) ? NULL : g_object_ref (_tmp0_)), (self->priv->dialog == NULL) ? NULL : (self->priv->dialog = (g_object_unref (self->priv->dialog), NULL)), _tmp1_);
+		_tmp3_ = NULL;
+		_tmp2_ = NULL;
+		self->protocolCombo = (_tmp3_ = (_tmp2_ = GTK_COMBO_BOX (gtk_builder_get_object (self->priv->_builder, "send_chooser_protocol")), (_tmp2_ == NULL) ? NULL : g_object_ref (_tmp2_)), (self->protocolCombo == NULL) ? NULL : (self->protocolCombo = (g_object_unref (self->protocolCombo), NULL)), _tmp3_);
 		g_signal_connect_object ((GtkWidget*) self->priv->dialog, "delete-event", (GCallback) _moserial_send_chooser_dialog_hide_gtk_widget_delete_event, self, 0);
 		gtk_dialog_add_buttons ((GtkDialog*) self->priv->dialog, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL, NULL);
 		gtk_combo_box_set_active (self->protocolCombo, 2);
@@ -150,35 +187,6 @@ static GObject * moserial_send_chooser_dialog_constructor (GType type, guint n_c
 }
 
 
-static void moserial_send_chooser_dialog_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	moserialSendChooserDialog * self;
-	gpointer boxed;
-	self = MOSERIAL_SEND_CHOOSER_DIALOG (object);
-	switch (property_id) {
-		case MOSERIAL_SEND_CHOOSER_DIALOG_BUILDER:
-		g_value_set_object (value, moserial_send_chooser_dialog_get_builder (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void moserial_send_chooser_dialog_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	moserialSendChooserDialog * self;
-	self = MOSERIAL_SEND_CHOOSER_DIALOG (object);
-	switch (property_id) {
-		case MOSERIAL_SEND_CHOOSER_DIALOG_BUILDER:
-		moserial_send_chooser_dialog_set_builder (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void moserial_send_chooser_dialog_class_init (moserialSendChooserDialogClass * klass) {
 	moserial_send_chooser_dialog_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (moserialSendChooserDialogPrivate));
@@ -217,5 +225,34 @@ GType moserial_send_chooser_dialog_get_type (void) {
 }
 
 
+static void moserial_send_chooser_dialog_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
+	moserialSendChooserDialog * self;
+	gpointer boxed;
+	self = MOSERIAL_SEND_CHOOSER_DIALOG (object);
+	switch (property_id) {
+		case MOSERIAL_SEND_CHOOSER_DIALOG_BUILDER:
+		g_value_set_object (value, moserial_send_chooser_dialog_get_builder (self));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
+
+static void moserial_send_chooser_dialog_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
+	moserialSendChooserDialog * self;
+	self = MOSERIAL_SEND_CHOOSER_DIALOG (object);
+	switch (property_id) {
+		case MOSERIAL_SEND_CHOOSER_DIALOG_BUILDER:
+		moserial_send_chooser_dialog_set_builder (self, g_value_get_object (value));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
+
 
 
