@@ -1,5 +1,8 @@
 
-#include <src/SerialConnection.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
 #include <termios.h>
 #include <fcntl.h>
 #include <unistd.h>
@@ -7,7 +10,50 @@
 #include <glib/gi18n-lib.h>
 
 
+#define MOSERIAL_TYPE_SERIAL_CONNECTION (moserial_serial_connection_get_type ())
+#define MOSERIAL_SERIAL_CONNECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MOSERIAL_TYPE_SERIAL_CONNECTION, moserialSerialConnection))
+#define MOSERIAL_SERIAL_CONNECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MOSERIAL_TYPE_SERIAL_CONNECTION, moserialSerialConnectionClass))
+#define MOSERIAL_IS_SERIAL_CONNECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MOSERIAL_TYPE_SERIAL_CONNECTION))
+#define MOSERIAL_IS_SERIAL_CONNECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MOSERIAL_TYPE_SERIAL_CONNECTION))
+#define MOSERIAL_SERIAL_CONNECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MOSERIAL_TYPE_SERIAL_CONNECTION, moserialSerialConnectionClass))
 
+typedef struct _moserialSerialConnection moserialSerialConnection;
+typedef struct _moserialSerialConnectionClass moserialSerialConnectionClass;
+typedef struct _moserialSerialConnectionPrivate moserialSerialConnectionPrivate;
+
+#define MOSERIAL_SERIAL_CONNECTION_TYPE_LINE_END (moserial_serial_connection_line_end_get_type ())
+
+#define SETTINGS_TYPE_ACCESS_MODE (settings_access_mode_get_type ())
+
+#define TYPE_SETTINGS (settings_get_type ())
+#define SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SETTINGS, Settings))
+#define SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SETTINGS, SettingsClass))
+#define IS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SETTINGS))
+#define IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SETTINGS))
+#define SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SETTINGS, SettingsClass))
+
+typedef struct _Settings Settings;
+typedef struct _SettingsClass SettingsClass;
+
+#define SETTINGS_TYPE_PARITY (settings_parity_get_type ())
+
+#define SETTINGS_TYPE_HANDSHAKE (settings_handshake_get_type ())
+
+struct _moserialSerialConnection {
+	GObject parent_instance;
+	moserialSerialConnectionPrivate * priv;
+	gulong tx;
+	gulong rx;
+	gulong nonprintable;
+	gboolean forced_hex_view;
+	gboolean lastRxCharWasCR;
+	char* echoReference;
+	char* echoCompare;
+};
+
+struct _moserialSerialConnectionClass {
+	GObjectClass parent_class;
+};
 
 struct _moserialSerialConnectionPrivate {
 	gboolean connected;
@@ -20,15 +66,69 @@ struct _moserialSerialConnectionPrivate {
 	gboolean localEcho;
 };
 
+typedef enum  {
+	MOSERIAL_SERIAL_CONNECTION_LINE_END_CRLF,
+	MOSERIAL_SERIAL_CONNECTION_LINE_END_CR,
+	MOSERIAL_SERIAL_CONNECTION_LINE_END_LF,
+	MOSERIAL_SERIAL_CONNECTION_LINE_END_TAB,
+	MOSERIAL_SERIAL_CONNECTION_LINE_END_ESC,
+	MOSERIAL_SERIAL_CONNECTION_LINE_END_NONE
+} moserialSerialConnectionLineEnd;
+
+typedef enum  {
+	SETTINGS_ACCESS_MODE_READWRITE,
+	SETTINGS_ACCESS_MODE_READONLY,
+	SETTINGS_ACCESS_MODE_WRITEONLY
+} SettingsAccessMode;
+
+typedef enum  {
+	SETTINGS_PARITY_NONE,
+	SETTINGS_PARITY_ODD,
+	SETTINGS_PARITY_EVEN,
+	SETTINGS_PARITY_MARK,
+	SETTINGS_PARITY_SPACE
+} SettingsParity;
+
+typedef enum  {
+	SETTINGS_HANDSHAKE_NONE,
+	SETTINGS_HANDSHAKE_HARDWARE,
+	SETTINGS_HANDSHAKE_SOFTWARE,
+	SETTINGS_HANDSHAKE_BOTH
+} SettingsHandshake;
+
+
+static gpointer moserial_serial_connection_parent_class = NULL;
+
+GType moserial_serial_connection_get_type (void);
 #define MOSERIAL_SERIAL_CONNECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), MOSERIAL_TYPE_SERIAL_CONNECTION, moserialSerialConnectionPrivate))
 enum  {
 	MOSERIAL_SERIAL_CONNECTION_DUMMY_PROPERTY
 };
+GType moserial_serial_connection_line_end_get_type (void);
+GType settings_access_mode_get_type (void);
+GType settings_get_type (void);
+SettingsAccessMode settings_get_accessMode (Settings* self);
+const char* settings_get_device (Settings* self);
+static void moserial_serial_connection_applySettings (moserialSerialConnection* self, Settings* settings);
+static gboolean moserial_serial_connection_readBytes (moserialSerialConnection* self, GIOChannel* source, GIOCondition condition);
 static gboolean _moserial_serial_connection_readBytes_gio_func (GIOChannel* source, GIOCondition condition, gpointer self);
 static guint* _uint_dup (guint* self);
-static gboolean moserial_serial_connection_readBytes (moserialSerialConnection* self, GIOChannel* source, GIOCondition condition);
-static void moserial_serial_connection_applySettings (moserialSerialConnection* self, Settings* settings);
-static gpointer moserial_serial_connection_parent_class = NULL;
+gboolean settings_get_localEcho (Settings* self);
+gboolean moserial_serial_connection_doConnect (moserialSerialConnection* self, Settings* settings);
+void moserial_serial_connection_sendByte (moserialSerialConnection* self, guchar byte);
+void moserial_serial_connection_sendBytes (moserialSerialConnection* self, gchar* bytes, int bytes_length1, gsize size);
+char* moserial_serial_connection_getLineEnd (moserialSerialConnection* self, gint e);
+void moserial_serial_connection_doDisconnect (moserialSerialConnection* self);
+gint settings_get_baudRate (Settings* self);
+gint settings_get_dataBits (Settings* self);
+GType settings_parity_get_type (void);
+SettingsParity settings_get_parity (Settings* self);
+gint settings_get_stopBits (Settings* self);
+GType settings_handshake_get_type (void);
+SettingsHandshake settings_get_handshake (Settings* self);
+char* moserial_serial_connection_getBytecountbarString (moserialSerialConnection* self);
+moserialSerialConnection* moserial_serial_connection_new (void);
+moserialSerialConnection* moserial_serial_connection_construct (GType object_type);
 static void moserial_serial_connection_finalize (GObject* obj);
 
 
@@ -59,11 +159,12 @@ static guint* _uint_dup (guint* self) {
 
 
 gboolean moserial_serial_connection_doConnect (moserialSerialConnection* self, Settings* settings) {
+	gboolean result;
 	gint n;
-	GIOChannel* _tmp1;
-	guint* _tmp4;
-	guint* _tmp3;
-	guint _tmp2;
+	GIOChannel* _tmp0_;
+	guint* _tmp3_;
+	guint* _tmp2_;
+	guint _tmp1_;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (settings != NULL, FALSE);
 	if (settings_get_accessMode (settings) == SETTINGS_ACCESS_MODE_READWRITE) {
@@ -79,7 +180,8 @@ gboolean moserial_serial_connection_doConnect (moserialSerialConnection* self, S
 	if (self->priv->m_fd < 0) {
 		self->priv->m_fd = -1;
 		/* TODO display error in gui*/
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
 	tcflush (self->priv->m_fd, TCIOFLUSH);
 	n = fcntl (self->priv->m_fd, F_GETFL);
@@ -88,24 +190,27 @@ gboolean moserial_serial_connection_doConnect (moserialSerialConnection* self, S
 	moserial_serial_connection_applySettings (self, settings);
 	tcsetattr (self->priv->m_fd, TCSANOW, &self->priv->newtio);
 	self->priv->connected = TRUE;
-	_tmp1 = NULL;
-	self->priv->IOChannelFd = (_tmp1 = g_io_channel_unix_new (self->priv->m_fd), (self->priv->IOChannelFd == NULL) ? NULL : (self->priv->IOChannelFd = (g_io_channel_unref (self->priv->IOChannelFd), NULL)), _tmp1);
-	self->priv->sourceId = (_tmp4 = (_tmp3 = (_tmp2 = g_io_add_watch (self->priv->IOChannelFd, G_IO_IN, _moserial_serial_connection_readBytes_gio_func, self), &_tmp2), (_tmp3 == NULL) ? NULL : _uint_dup (_tmp3)), (self->priv->sourceId == NULL) ? NULL : (self->priv->sourceId = (g_free (self->priv->sourceId), NULL)), _tmp4);
+	_tmp0_ = NULL;
+	self->priv->IOChannelFd = (_tmp0_ = g_io_channel_unix_new (self->priv->m_fd), (self->priv->IOChannelFd == NULL) ? NULL : (self->priv->IOChannelFd = (g_io_channel_unref (self->priv->IOChannelFd), NULL)), _tmp0_);
+	_tmp3_ = NULL;
+	_tmp2_ = NULL;
+	self->priv->sourceId = (_tmp3_ = (_tmp2_ = (_tmp1_ = g_io_add_watch (self->priv->IOChannelFd, G_IO_IN, _moserial_serial_connection_readBytes_gio_func, self), &_tmp1_), (_tmp2_ == NULL) ? NULL : _uint_dup (_tmp2_)), (self->priv->sourceId == NULL) ? NULL : (self->priv->sourceId = (g_free (self->priv->sourceId), NULL)), _tmp3_);
 	self->priv->localEcho = settings_get_localEcho (settings);
-	return TRUE;
+	result = TRUE;
+	return result;
 }
 
 
 void moserial_serial_connection_sendByte (moserialSerialConnection* self, guchar byte) {
 	g_return_if_fail (self != NULL);
 	if (self->priv->connected) {
-		guchar* _tmp0;
+		guchar* _tmp0_;
 		gint b_size;
 		gint b_length1;
 		guchar* b;
 		gsize x;
-		_tmp0 = NULL;
-		b = (_tmp0 = g_new0 (guchar, 1), b_length1 = 1, b_size = b_length1, _tmp0);
+		_tmp0_ = NULL;
+		b = (_tmp0_ = g_new0 (guchar, 1), b_length1 = 1, b_size = b_length1, _tmp0_);
 		b[0] = byte;
 		x = (gsize) write (self->priv->m_fd, b, (gsize) 1);
 		/*POSIX.Termios.drain(m_fd);*/
@@ -127,6 +232,7 @@ void moserial_serial_connection_sendBytes (moserialSerialConnection* self, gchar
 
 
 char* moserial_serial_connection_getLineEnd (moserialSerialConnection* self, gint e) {
+	char* result;
 	char* s;
 	g_return_val_if_fail (self != NULL, NULL);
 	s = NULL;
@@ -134,77 +240,79 @@ char* moserial_serial_connection_getLineEnd (moserialSerialConnection* self, gin
 		case MOSERIAL_SERIAL_CONNECTION_LINE_END_CR:
 		{
 			{
-				char* _tmp0;
-				_tmp0 = NULL;
-				s = (_tmp0 = g_strdup ("\r"), s = (g_free (s), NULL), _tmp0);
+				char* _tmp0_;
+				_tmp0_ = NULL;
+				s = (_tmp0_ = g_strdup ("\r"), s = (g_free (s), NULL), _tmp0_);
 				break;
 			}
 		}
 		case MOSERIAL_SERIAL_CONNECTION_LINE_END_LF:
 		{
 			{
-				char* _tmp1;
-				_tmp1 = NULL;
-				s = (_tmp1 = g_strdup ("\n"), s = (g_free (s), NULL), _tmp1);
+				char* _tmp1_;
+				_tmp1_ = NULL;
+				s = (_tmp1_ = g_strdup ("\n"), s = (g_free (s), NULL), _tmp1_);
 				break;
 			}
 		}
 		case MOSERIAL_SERIAL_CONNECTION_LINE_END_CRLF:
 		{
 			{
-				char* _tmp2;
-				_tmp2 = NULL;
-				s = (_tmp2 = g_strdup ("\r\n"), s = (g_free (s), NULL), _tmp2);
+				char* _tmp2_;
+				_tmp2_ = NULL;
+				s = (_tmp2_ = g_strdup ("\r\n"), s = (g_free (s), NULL), _tmp2_);
 				break;
 			}
 		}
 		case MOSERIAL_SERIAL_CONNECTION_LINE_END_TAB:
 		{
 			{
-				char* _tmp3;
-				_tmp3 = NULL;
-				s = (_tmp3 = g_strdup ("\t"), s = (g_free (s), NULL), _tmp3);
+				char* _tmp3_;
+				_tmp3_ = NULL;
+				s = (_tmp3_ = g_strdup ("\t"), s = (g_free (s), NULL), _tmp3_);
 				break;
 			}
 		}
 		case MOSERIAL_SERIAL_CONNECTION_LINE_END_ESC:
 		{
 			{
-				char* _tmp4;
-				_tmp4 = NULL;
-				s = (_tmp4 = g_strdup ("\x1b"), s = (g_free (s), NULL), _tmp4);
+				char* _tmp4_;
+				_tmp4_ = NULL;
+				s = (_tmp4_ = g_strdup ("\x1b"), s = (g_free (s), NULL), _tmp4_);
 				break;
 			}
 		}
 		default:
 		{
 			{
-				char* _tmp5;
-				_tmp5 = NULL;
-				s = (_tmp5 = g_strdup (""), s = (g_free (s), NULL), _tmp5);
+				char* _tmp5_;
+				_tmp5_ = NULL;
+				s = (_tmp5_ = g_strdup (""), s = (g_free (s), NULL), _tmp5_);
 				break;
 			}
 		}
 	}
-	return s;
+	result = s;
+	return result;
 }
 
 
 void moserial_serial_connection_doDisconnect (moserialSerialConnection* self) {
-	GError * inner_error;
+	GError * _inner_error_;
 	g_return_if_fail (self != NULL);
-	inner_error = NULL;
+	_inner_error_ = NULL;
 	if (self->priv->connected) {
-		guint* _tmp0;
-		GIOChannel* _tmp1;
-		char* _tmp2;
-		char* _tmp3;
+		guint* _tmp0_;
+		GIOChannel* _tmp1_;
+		char* _tmp2_;
+		char* _tmp3_;
 		g_source_remove (*self->priv->sourceId);
-		self->priv->sourceId = (_tmp0 = NULL, (self->priv->sourceId == NULL) ? NULL : (self->priv->sourceId = (g_free (self->priv->sourceId), NULL)), _tmp0);
+		_tmp0_ = NULL;
+		self->priv->sourceId = (_tmp0_ = NULL, (self->priv->sourceId == NULL) ? NULL : (self->priv->sourceId = (g_free (self->priv->sourceId), NULL)), _tmp0_);
 		{
-			g_io_channel_shutdown (self->priv->IOChannelFd, TRUE, &inner_error);
-			if (inner_error != NULL) {
-				if (inner_error->domain == G_IO_CHANNEL_ERROR) {
+			g_io_channel_shutdown (self->priv->IOChannelFd, TRUE, &_inner_error_);
+			if (_inner_error_ != NULL) {
+				if (_inner_error_->domain == G_IO_CHANNEL_ERROR) {
 					goto __catch6_g_io_channel_error;
 				}
 				goto __finally6;
@@ -214,29 +322,29 @@ void moserial_serial_connection_doDisconnect (moserialSerialConnection* self) {
 		__catch6_g_io_channel_error:
 		{
 			GError * e;
-			e = inner_error;
-			inner_error = NULL;
+			e = _inner_error_;
+			_inner_error_ = NULL;
 			{
 				g_warning ("SerialConnection.vala:116: %s", e->message);
 				(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
 			}
 		}
 		__finally6:
-		if (inner_error != NULL) {
-			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-			g_clear_error (&inner_error);
+		if (_inner_error_ != NULL) {
+			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
+			g_clear_error (&_inner_error_);
 			return;
 		}
-		_tmp1 = NULL;
-		self->priv->IOChannelFd = (_tmp1 = NULL, (self->priv->IOChannelFd == NULL) ? NULL : (self->priv->IOChannelFd = (g_io_channel_unref (self->priv->IOChannelFd), NULL)), _tmp1);
+		_tmp1_ = NULL;
+		self->priv->IOChannelFd = (_tmp1_ = NULL, (self->priv->IOChannelFd == NULL) ? NULL : (self->priv->IOChannelFd = (g_io_channel_unref (self->priv->IOChannelFd), NULL)), _tmp1_);
 		self->priv->connected = FALSE;
 		self->forced_hex_view = FALSE;
 		self->lastRxCharWasCR = FALSE;
 		self->tx = self->rx = self->nonprintable = (gulong) 0;
-		_tmp2 = NULL;
-		self->echoReference = (_tmp2 = g_strdup (""), self->echoReference = (g_free (self->echoReference), NULL), _tmp2);
-		_tmp3 = NULL;
-		self->echoCompare = (_tmp3 = g_strdup (""), self->echoCompare = (g_free (self->echoCompare), NULL), _tmp3);
+		_tmp2_ = NULL;
+		self->echoReference = (_tmp2_ = g_strdup (""), self->echoReference = (g_free (self->echoReference), NULL), _tmp2_);
+		_tmp3_ = NULL;
+		self->echoCompare = (_tmp3_ = g_strdup (""), self->echoCompare = (g_free (self->echoCompare), NULL), _tmp3_);
 		tcsetattr (self->priv->m_fd, TCSANOW, &self->priv->newtio);
 		close (self->priv->m_fd);
 	}
@@ -244,37 +352,40 @@ void moserial_serial_connection_doDisconnect (moserialSerialConnection* self) {
 
 
 static gboolean moserial_serial_connection_readBytes (moserialSerialConnection* self, GIOChannel* source, GIOCondition condition) {
-	guchar* _tmp0;
+	gboolean result;
+	guchar* _tmp0_;
 	gint m_buf_size;
 	gint m_buf_length1;
 	guchar* m_buf;
 	gint bytesRead;
-	gboolean _tmp2;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (source != NULL, FALSE);
-	_tmp0 = NULL;
-	m_buf = (_tmp0 = g_new0 (guchar, 1000), m_buf_length1 = 1000, m_buf_size = m_buf_length1, _tmp0);
+	_tmp0_ = NULL;
+	m_buf = (_tmp0_ = g_new0 (guchar, 1000), m_buf_length1 = 1000, m_buf_size = m_buf_length1, _tmp0_);
 	bytesRead = (gint) read (self->priv->m_fd, m_buf, (gsize) 1000);
 	self->rx = self->rx + ((gulong) bytesRead);
 	if (bytesRead < 0) {
-		gboolean _tmp1;
-		return (_tmp1 = FALSE, m_buf = (g_free (m_buf), NULL), _tmp1);
+		result = FALSE;
+		m_buf = (g_free (m_buf), NULL);
+		return result;
 	}
 	g_signal_emit_by_name (self, "new-data", m_buf, m_buf_length1, bytesRead);
 	if (self->priv->localEcho) {
-		moserial_serial_connection_sendBytes (self, (gchar*) m_buf, -1, (gsize) bytesRead);
+		moserial_serial_connection_sendBytes (self, (gchar*) m_buf, m_buf_length1, (gsize) bytesRead);
 	}
-	return (_tmp2 = self->priv->connected, m_buf = (g_free (m_buf), NULL), _tmp2);
+	result = self->priv->connected;
+	m_buf = (g_free (m_buf), NULL);
+	return result;
 }
 
 
 static void moserial_serial_connection_applySettings (moserialSerialConnection* self, Settings* settings) {
 	guint baudRate;
 	gint dataBits;
-	gboolean _tmp0;
-	gboolean _tmp2;
+	gboolean _tmp0_;
+	gboolean _tmp2_;
 	gint mcs;
-	gboolean _tmp3;
+	gboolean _tmp3_;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (settings != NULL);
 	/*BaudRate*/
@@ -366,21 +477,21 @@ static void moserial_serial_connection_applySettings (moserialSerialConnection*
 	/*DataBits*/
 	dataBits = 0;
 	dataBits = settings_get_dataBits (settings);
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (settings_get_dataBits (settings) == 7) {
-		gboolean _tmp1;
-		_tmp1 = FALSE;
+		gboolean _tmp1_;
+		_tmp1_ = FALSE;
 		if (settings_get_parity (settings) == SETTINGS_PARITY_MARK) {
-			_tmp1 = TRUE;
+			_tmp1_ = TRUE;
 		} else {
-			_tmp1 = settings_get_parity (settings) == SETTINGS_PARITY_SPACE;
+			_tmp1_ = settings_get_parity (settings) == SETTINGS_PARITY_SPACE;
 		}
-		_tmp0 = _tmp1;
+		_tmp0_ = _tmp1_;
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
 	/* We generate mark and space parity*/
-	if (_tmp0) {
+	if (_tmp0_) {
 		dataBits = 8;
 	}
 	switch (dataBits) {
@@ -424,14 +535,14 @@ static void moserial_serial_connection_applySettings (moserialSerialConnection*
 	}
 	/*Input Settings*/
 	self->priv->newtio.c_iflag = IGNBRK;
-	_tmp2 = FALSE;
+	_tmp2_ = FALSE;
 	if (settings_get_handshake (settings) == SETTINGS_HANDSHAKE_SOFTWARE) {
-		_tmp2 = TRUE;
+		_tmp2_ = TRUE;
 	} else {
-		_tmp2 = settings_get_handshake (settings) == SETTINGS_HANDSHAKE_BOTH;
+		_tmp2_ = settings_get_handshake (settings) == SETTINGS_HANDSHAKE_BOTH;
 	}
 	/*Handshake*/
-	if (_tmp2) {
+	if (_tmp2_) {
 		self->priv->newtio.c_iflag = self->priv->newtio.c_iflag | (IXON | IXOFF);
 	} else {
 		self->priv->newtio.c_iflag = self->priv->newtio.c_iflag & (~((IXON | IXOFF) | IXANY));
@@ -454,13 +565,13 @@ static void moserial_serial_connection_applySettings (moserialSerialConnection*
 	ioctl (self->priv->m_fd, TIOCMGET, &mcs);
 	mcs = mcs | TIOCM_RTS;
 	ioctl (self->priv->m_fd, TIOCMSET, &mcs);
-	_tmp3 = FALSE;
+	_tmp3_ = FALSE;
 	if (settings_get_handshake (settings) == SETTINGS_HANDSHAKE_HARDWARE) {
-		_tmp3 = TRUE;
+		_tmp3_ = TRUE;
 	} else {
-		_tmp3 = settings_get_handshake (settings) == SETTINGS_HANDSHAKE_BOTH;
+		_tmp3_ = settings_get_handshake (settings) == SETTINGS_HANDSHAKE_BOTH;
 	}
-	if (_tmp3) {
+	if (_tmp3_) {
 		self->priv->newtio.c_cflag = self->priv->newtio.c_cflag | CRTSCTS;
 	} else {
 		self->priv->newtio.c_cflag = self->priv->newtio.c_cflag & (~CRTSCTS);
@@ -469,19 +580,21 @@ static void moserial_serial_connection_applySettings (moserialSerialConnection*
 
 
 char* moserial_serial_connection_getBytecountbarString (moserialSerialConnection* self) {
+	char* result;
 	char* r;
 	g_return_val_if_fail (self != NULL, NULL);
 	r = NULL;
 	if (self->nonprintable > 0) {
-		char* _tmp0;
-		_tmp0 = NULL;
-		r = (_tmp0 = g_strdup_printf (_ ("TX: %lu, RX: %lu (%lu unprintable)"), self->tx, self->rx, self->nonprintable), r = (g_free (r), NULL), _tmp0);
+		char* _tmp0_;
+		_tmp0_ = NULL;
+		r = (_tmp0_ = g_strdup_printf (_ ("TX: %lu, RX: %lu (%lu unprintable)"), self->tx, self->rx, self->nonprintable), r = (g_free (r), NULL), _tmp0_);
 	} else {
-		char* _tmp1;
-		_tmp1 = NULL;
-		r = (_tmp1 = g_strdup_printf (_ ("TX: %lu, RX: %lu"), self->tx, self->rx), r = (g_free (r), NULL), _tmp1);
+		char* _tmp1_;
+		_tmp1_ = NULL;
+		r = (_tmp1_ = g_strdup_printf (_ ("TX: %lu, RX: %lu"), self->tx, self->rx), r = (g_free (r), NULL), _tmp1_);
 	}
-	return r;
+	result = r;
+	return result;
 }
 
 
